@@ -1,7 +1,7 @@
 # ABSTRACT: TestRail testing harness
 # PODNAME: Test::Rail::Harness
 package Test::Rail::Harness;
-$Test::Rail::Harness::VERSION = '0.031';
+$Test::Rail::Harness::VERSION = '0.032';
 use strict;
 use warnings;
 
@@ -45,9 +45,13 @@ sub make_parser {
     $args->{'sections'} = \@sections if scalar(@sections);
     $args->{'autoclose'} = $ENV{'TESTRAIL_AUTOCLOSE'};
 
-    #for Testability of plugin
+    #for Testability of plugin XXX probably some of the last remaining grotiness
     if ( $ENV{'TESTRAIL_MOCKED'} ) {
-        require 't/lib/Test/LWP/UserAgent/TestRailMock.pm';    ## no critic
+        use lib 't/lib'
+          ;    #Unit tests will always run from the main dir during make test
+        if ( !defined $Test::LWP::UserAgent::TestRailMock::mockObject ) {
+            require 't/lib/Test/LWP/UserAgent/TestRailMock.pm';    ## no critic
+        }
         $args->{'debug'}   = 1;
         $args->{'browser'} = $Test::LWP::UserAgent::TestRailMock::mockObject;
     }
@@ -76,7 +80,7 @@ Test::Rail::Harness - TestRail testing harness
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 DESCRIPTION
 
