@@ -2,12 +2,13 @@
 # PODNAME: TestRail::Utils
 
 package TestRail::Utils;
-$TestRail::Utils::VERSION = '0.031';
+$TestRail::Utils::VERSION = '0.032';
 use strict;
 use warnings;
 
 use Carp qw{confess cluck};
 use Pod::Perldoc 3.20;    #Make sure we have ToMan on some unices
+use TestRail::API;
 
 use IO::Interactive::Tiny ();
 use Term::ANSIColor 2.01 qw(colorstrip);
@@ -16,7 +17,7 @@ use Scalar::Util qw{blessed};
 sub help {
     @ARGV = ($0);
     Pod::Perldoc->run();
-    exit 0;
+    return 0;
 }
 
 sub userInput {
@@ -168,16 +169,14 @@ sub getRunInformation {
 sub getHandle {
     my $opts = shift;
 
-    $opts->{'debug'} = 1 if ( $opts->{'mock'} );
+    $opts->{'debug'} = 1 if ( $opts->{'browser'} );
+
     my $tr = TestRail::API->new(
         $opts->{apiurl},     $opts->{user}, $opts->{password},
         $opts->{'encoding'}, $opts->{'debug'}
     );
-    if ( $opts->{'mock'} ) {
-        use lib 't/lib'
-          ;    #Unit tests will always run from the main dir during make test
-        require 't/lib/Test/LWP/UserAgent/TestRailMock.pm';    ## no critic
-        $tr->{'browser'} = $Test::LWP::UserAgent::TestRailMock::mockObject;
+    if ( $opts->{'browser'} ) {
+        $tr->{'browser'} = $opts->{'browser'};
         $tr->{'debug'}   = 0;
     }
     return $tr;
@@ -197,7 +196,7 @@ TestRail::Utils - Utilities for the testrail command line functions, and their m
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SCRIPT HELPER FUNCTIONS
 
