@@ -2,7 +2,7 @@
 # ABSTRACT: Find runs and tests according to user specifications.
 
 package TestRail::Utils::Find;
-$TestRail::Utils::Find::VERSION = '0.031';
+$TestRail::Utils::Find::VERSION = '0.032';
 use strict;
 use warnings;
 
@@ -123,13 +123,21 @@ sub findTests {
 
     confess "Error! match and no-match options are mutually exclusive.\n"
       if ( $opts->{'match'} && $opts->{'no-match'} );
+    confess "Error! match and orphans options are mutually exclusive.\n"
+      if ( $opts->{'match'} && $opts->{'orphans'} );
+    confess "Error! no-match and orphans options are mutually exclusive.\n"
+      if ( $opts->{'orphans'} && $opts->{'no-match'} );
     my @tests = @cases;
     my (@realtests);
     my $ext = $opts->{'extension'} // '';
 
-    if ( $opts->{'match'} || $opts->{'no-match'} ) {
+    if ( $opts->{'match'} || $opts->{'no-match'} || $opts->{'orphans'} ) {
         my @tmpArr = ();
-        my $dir = $opts->{'match'} ? $opts->{'match'} : $opts->{'no-match'};
+        my $dir =
+            ( $opts->{'match'} || $opts->{'orphans'} )
+          ? ( $opts->{'match'} || $opts->{'orphans'} )
+          : $opts->{'no-match'};
+        confess "No such directory '$dir'" if !-d $dir;
         if ( !$opts->{'no-recurse'} ) {
             File::Find::find(
                 sub {
@@ -150,7 +158,11 @@ sub findTests {
                 last;
             }
         }
-        @tests = @tmpArr;    #XXX if you have dups in your tree, be-ware
+        @tmpArr = grep {
+            my $otest = $_;
+            !( grep { $otest->{'title'} eq $_->{'title'} } @tmpArr )
+        } @tests if $opts->{'orphans'};
+        @tests = @tmpArr;
         @tests = map { { 'title' => $_ } } grep {
             my $otest = basename($_);
             scalar( grep { basename( $_->{'title'} ) eq $otest } @tests ) == 0
@@ -167,6 +179,84 @@ sub findTests {
     return @tests;
 }
 
+sub getCases {
+    my ( $opts, $tr ) = @_;
+    confess("First argument must be instance of TestRail::API")
+      unless blessed($tr) eq 'TestRail::API';
+
+    my $project = $tr->getProjectByName( $opts->{'project'} );
+    confess "No such project '$opts->{project}'.\n" if !$project;
+
+    my $suite =
+      $tr->getTestSuiteByName( $project->{'id'}, $opts->{'testsuite'} );
+    confess "No such testsuite '$opts->{testsuite}'.\n" if !$suite;
+    $opts->{'testsuite_id'} = $suite->{'id'};
+
+    my $section;
+    $section =
+      $tr->getSectionByName( $project->{'id'}, $suite->{'id'},
+        $opts->{'section'} )
+      if $opts->{'section'};
+    confess "No such section '$opts->{section}.\n"
+      if $opts->{'section'} && !$section;
+
+    my $section_id;
+    $section_id = $section->{'id'} if ref $section eq "HASH";
+
+    my $type_ids;
+    @$type_ids = $tr->typeNamesToIds( @{ $opts->{'types'} } )
+      if ref $opts->{'types'} eq 'ARRAY';
+
+    #Above will confess if anything's the matter
+
+    #TODO Translate opts into filters
+    my $filters = {
+        'section_id' => $section_id,
+        'type_id'    => $type_ids
+    };
+
+    return $tr->getCases( $project->{'id'}, $suite->{'id'}, $filters );
+}
+
+sub findCases {
+    my ( $opts, @cases ) = @_;
+
+    confess('testsuite_id parameter mandatory in options HASHREF')
+      unless defined $opts->{'testsuite_id'};
+    confess('Directory parameter mandatory in options HASHREF.')
+      unless defined $opts->{'directory'};
+    confess( 'No such directory "' . $opts->{'directory'} . "\"\n" )
+      unless -d $opts->{'directory'};
+
+    my $ret = { 'testsuite_id' => $opts->{'testsuite_id'} };
+    if ( !$opts->{'no-missing'} ) {
+        my $mopts = {
+            'no-match'   => $opts->{'directory'},
+            'names-only' => 1,
+            'extension'  => $opts->{'extension'}
+        };
+        my @missing = findTests( $mopts, @cases );
+        $ret->{'missing'} = \@missing;
+    }
+    if ( $opts->{'orphans'} ) {
+        my $oopts = {
+            'orphans'   => $opts->{'directory'},
+            'extension' => $opts->{'extension'}
+        };
+        my @orphans = findTests( $oopts, @cases );
+        $ret->{'orphans'} = \@orphans;
+    }
+    if ( $opts->{'update'} ) {
+        my $uopts = {
+            'match'     => $opts->{'directory'},
+            'extension' => $opts->{'extension'}
+        };
+        my @updates = findTests( $uopts, @cases );
+        $ret->{'update'} = \@updates;
+    }
+    return $ret;
+}
+
 1;
 
 __END__
@@ -181,7 +271,7 @@ TestRail::Utils::Find - Find runs and tests according to user specifications.
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 DESCRIPTION
 
@@ -242,9 +332,11 @@ Given an ARRAY of tests, find tests meeting your criteria (or not) in the specif
 
 =over 4
 
-=item STRING C<MATCH> - Only return tests which exist in the path provided.  Mutually exclusive with no-match.
+=item STRING C<MATCH> - Only return tests which exist in the path provided, and in TestRail.  Mutually exclusive with no-match, orphans.
 
-=item STRING C<NO-MATCH> - Only return tests which aren't in the path provided (orphan tests).  Mutually exclusive with match.
+=item STRING C<NO-MATCH> - Only return tests which are in the path provided, but not in TestRail.  Mutually exclusive with match, orphans.
+
+=item STRING C<ORPHANS> - Only return tests which are in TestRail, and not in the path provided.  Mutually exclusive with match, no-match
 
 =item BOOL C<NO-RECURSE> - Do not do a recursive scan for files.
 
@@ -262,6 +354,20 @@ Returns tests found that meet the criteria laid out in the options.
 Provides absolute path to tests if match is passed; this is the 'full_title' key if names-only is false/undef.
 Dies if mutually exclusive options are passed.
 
+=head2 getCases
+
+Get cases in a testsuite matching your parameters passed
+
+=head2 findCases(opts,@cases)
+
+Find orphan, missing and needing-update cases.
+They are returned as the hash keys 'orphans', 'missing', and 'updates' respectively.
+The testsuite_id is also returned in the output hashref.
+
+Option hash keys for input are 'no-missing', 'orphans', and 'update'.
+
+Returns HASHREF.
+
 =head1 SPECIAL THANKS
 
 Thanks to cPanel Inc, for graciously funding the creation of this module.
